summaryrefslogtreecommitdiff
path: root/solenv
diff options
context:
space:
mode:
authorTor Lillqvist <tlillqvist@suse.com>2012-04-03 08:55:28 +0300
committerTor Lillqvist <tlillqvist@suse.com>2012-04-03 14:43:43 +0300
commit4e8bc5911164971a9af5377633803ec620f593cc (patch)
treef31b00d67e4d0b7f644761846321a22063633fbc /solenv
parent2d691f26c6d4fd6fac11559f9b5b854d306e137a (diff)
s/pathes/paths/
Diffstat (limited to 'solenv')
-rw-r--r--solenv/bin/make_installer.pl14
-rw-r--r--solenv/bin/modules/installer/download.pm4
-rw-r--r--solenv/bin/modules/installer/globals.pm4
-rw-r--r--solenv/bin/modules/installer/helppack.pm2
-rw-r--r--solenv/bin/modules/installer/languagepack.pm2
-rw-r--r--solenv/bin/modules/installer/packagelist.pm8
-rw-r--r--solenv/bin/modules/installer/scriptitems.pm8
-rw-r--r--solenv/bin/modules/installer/windows/file.pm2
-rw-r--r--solenv/bin/modules/installer/windows/msiglobal.pm2
-rw-r--r--solenv/bin/modules/installer/windows/strip.pm2
-rw-r--r--solenv/bin/modules/installer/worker.pm42
-rw-r--r--solenv/bin/modules/installer/ziplist.pm18
-rw-r--r--solenv/bin/modules/par2script/work.pm2
-rw-r--r--solenv/bin/par2script.pl2
14 files changed, 56 insertions, 56 deletions
diff --git a/solenv/bin/make_installer.pl b/solenv/bin/make_installer.pl
index 7d0f56ad29ef..21f207730959 100644
--- a/solenv/bin/make_installer.pl
+++ b/solenv/bin/make_installer.pl
@@ -276,13 +276,13 @@ if ( $$includepathref eq "" )
my $includepatharrayref = installer::converter::convert_stringlist_into_array($includepathref, ",");
-installer::ziplist::replace_all_variables_in_pathes($includepatharrayref, $pathvariableshashref);
+installer::ziplist::replace_all_variables_in_paths($includepatharrayref, $pathvariableshashref);
-installer::ziplist::replace_minor_in_pathes($includepatharrayref);
+installer::ziplist::replace_minor_in_paths($includepatharrayref);
-installer::ziplist::replace_packagetype_in_pathes($includepatharrayref);
+installer::ziplist::replace_packagetype_in_paths($includepatharrayref);
-installer::ziplist::resolve_relative_pathes($includepatharrayref);
+installer::ziplist::resolve_relative_paths($includepatharrayref);
installer::ziplist::remove_ending_separator($includepatharrayref);
@@ -291,7 +291,7 @@ installer::ziplist::remove_ending_separator($includepatharrayref);
# paths in global hashes.
##############################################
-installer::worker::collect_all_files_from_includepathes($includepatharrayref);
+installer::worker::collect_all_files_from_includepaths($includepatharrayref);
##############################################
# Analyzing languages in zip.lst if required
@@ -636,9 +636,9 @@ for ( my $n = 0; $n <= $#installer::globals::languageproducts; $n++ )
# Resolving include paths (language dependent)
################################################
- $includepatharrayref_lang = installer::ziplist::replace_languages_in_pathes($includepatharrayref, $languagesarrayref);
+ $includepatharrayref_lang = installer::ziplist::replace_languages_in_paths($includepatharrayref, $languagesarrayref);
- if ( $installer::globals::refresh_includepathes ) { installer::worker::collect_all_files_from_includepathes($includepatharrayref_lang); }
+ if ( $installer::globals::refresh_includepaths ) { installer::worker::collect_all_files_from_includepaths($includepatharrayref_lang); }
installer::ziplist::list_all_files_from_include_path($includepatharrayref_lang);
diff --git a/solenv/bin/modules/installer/download.pm b/solenv/bin/modules/installer/download.pm
index facdd160b7d9..b7a96dc70849 100644
--- a/solenv/bin/modules/installer/download.pm
+++ b/solenv/bin/modules/installer/download.pm
@@ -204,7 +204,7 @@ sub get_path_for_library
my $getuidlibraryref = "";
- if ( $installer::globals::include_pathes_read )
+ if ( $installer::globals::include_paths_read )
{
$getuidlibraryref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$getuidlibraryname, $includepatharrayref, 0);
}
@@ -954,7 +954,7 @@ sub create_download_sets
my $scriptref = "";
- if ( $installer::globals::include_pathes_read )
+ if ( $installer::globals::include_paths_read )
{
$scriptref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$scriptfilename, $includepatharrayref, 0);
}
diff --git a/solenv/bin/modules/installer/globals.pm b/solenv/bin/modules/installer/globals.pm
index 6d8785a3b601..c07f3f6913aa 100644
--- a/solenv/bin/modules/installer/globals.pm
+++ b/solenv/bin/modules/installer/globals.pm
@@ -323,8 +323,8 @@ BEGIN
$tab = 0;
$patch = 0;
$patchincludepath = "";
- $refresh_includepathes = 0;
- $include_pathes_read = 0;
+ $refresh_includepaths = 0;
+ $include_paths_read = 0;
$patchfilelistname = "patchfilelist.txt";
@patchfilecollector = ();
$nopatchfilecollector = "";
diff --git a/solenv/bin/modules/installer/helppack.pm b/solenv/bin/modules/installer/helppack.pm
index a6a9627c64f6..8eba3f366d78 100644
--- a/solenv/bin/modules/installer/helppack.pm
+++ b/solenv/bin/modules/installer/helppack.pm
@@ -494,7 +494,7 @@ sub build_installer_for_helppack
# find and read english license file
my $licenselanguage = "en-US"; # always english !
my $licensefilename = "LICENSE"; # _" . $licenselanguage;
- my $licenseincludepatharrayref = installer::worker::get_language_specific_include_pathes($includepatharrayref, $licenselanguage);
+ my $licenseincludepatharrayref = installer::worker::get_language_specific_include_paths($includepatharrayref, $licenselanguage);
my $licenseref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$licensefilename, $licenseincludepatharrayref, 0);
if ($$licenseref eq "") { installer::exiter::exit_program("ERROR: Could not find License file $licensefilename!", "build_installer_for_helppack"); }
diff --git a/solenv/bin/modules/installer/languagepack.pm b/solenv/bin/modules/installer/languagepack.pm
index 1bfcd8a37678..1e1639c25dce 100644
--- a/solenv/bin/modules/installer/languagepack.pm
+++ b/solenv/bin/modules/installer/languagepack.pm
@@ -474,7 +474,7 @@ sub build_installer_for_languagepack
# find and read english license file
my $licenselanguage = "en-US"; # always english !
my $licensefilename = "LICENSE"; # _" . $licenselanguage;
- my $licenseincludepatharrayref = installer::worker::get_language_specific_include_pathes($includepatharrayref, $licenselanguage);
+ my $licenseincludepatharrayref = installer::worker::get_language_specific_include_paths($includepatharrayref, $licenselanguage);
my $licenseref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$licensefilename, $licenseincludepatharrayref, 0);
if ($$licenseref eq "") { installer::exiter::exit_program("ERROR: Could not find License file $licensefilename!", "build_installer_for_languagepack"); }
diff --git a/solenv/bin/modules/installer/packagelist.pm b/solenv/bin/modules/installer/packagelist.pm
index e39917cebe39..0612ecb3257a 100644
--- a/solenv/bin/modules/installer/packagelist.pm
+++ b/solenv/bin/modules/installer/packagelist.pm
@@ -759,7 +759,7 @@ sub create_module_destination_hash
# fileinfo log file.
#####################################################################
-sub add_defaultpathes_into_filescollector
+sub add_defaultpaths_into_filescollector
{
my ($allfiles) = @_;
@@ -767,15 +767,15 @@ sub add_defaultpathes_into_filescollector
{
my $onefile = ${$allfiles}[$i];
- if ( ! $onefile->{'destination'} ) { installer::exiter::exit_program("ERROR: No destination found at file $onefile->{'gid'}!", "add_defaultpathes_into_filescollector"); }
+ if ( ! $onefile->{'destination'} ) { installer::exiter::exit_program("ERROR: No destination found at file $onefile->{'gid'}!", "add_defaultpaths_into_filescollector"); }
my $destination = $onefile->{'destination'};
- if ( ! $onefile->{'modules'} ) { installer::exiter::exit_program("ERROR: No modules found at file $onefile->{'gid'}!", "add_defaultpathes_into_filescollector"); }
+ if ( ! $onefile->{'modules'} ) { installer::exiter::exit_program("ERROR: No modules found at file $onefile->{'gid'}!", "add_defaultpaths_into_filescollector"); }
my $module = $onefile->{'modules'};
# If modules contains a list of modules, only taking the first one.
if ( $module =~ /^\s*(.*?)\,/ ) { $module = $1; }
- if ( ! exists($installer::globals::moduledestination{$module}) ) { installer::exiter::exit_program("ERROR: No default destination path found for module $module!", "add_defaultpathes_into_filescollector"); }
+ if ( ! exists($installer::globals::moduledestination{$module}) ) { installer::exiter::exit_program("ERROR: No default destination path found for module $module!", "add_defaultpaths_into_filescollector"); }
my $defaultpath = $installer::globals::moduledestination{$module};
$defaultpath =~ s/\/\s*$//; # removing ending slashes
my $fulldestpath = $defaultpath . $installer::globals::separator . $destination;
diff --git a/solenv/bin/modules/installer/scriptitems.pm b/solenv/bin/modules/installer/scriptitems.pm
index a1cbbbf95609..ad42ab15c0de 100644
--- a/solenv/bin/modules/installer/scriptitems.pm
+++ b/solenv/bin/modules/installer/scriptitems.pm
@@ -1090,9 +1090,9 @@ sub get_sourcepath_from_filename_and_includepath
my $foundsourcefile = 0;
my $foundnewname = 0;
- for ( my $j = 0; $j <= $#installer::globals::allincludepathes; $j++ )
+ for ( my $j = 0; $j <= $#installer::globals::allincludepaths; $j++ )
{
- my $allfiles = $installer::globals::allincludepathes[$j];
+ my $allfiles = $installer::globals::allincludepaths[$j];
if ( exists( $allfiles->{$$searchfilenameref} ))
{
@@ -1106,9 +1106,9 @@ sub get_sourcepath_from_filename_and_includepath
{
# Attention: README01.html is copied for Windows to readme01.html, not case sensitive
- for ( my $j = 0; $j <= $#installer::globals::allincludepathes; $j++ )
+ for ( my $j = 0; $j <= $#installer::globals::allincludepaths; $j++ )
{
- my $allfiles = $installer::globals::allincludepathes[$j];
+ my $allfiles = $installer::globals::allincludepaths[$j];
my $newfilename = $$searchfilenameref;
$newfilename =~ s/readme/README/; # special handling for readme files
diff --git a/solenv/bin/modules/installer/windows/file.pm b/solenv/bin/modules/installer/windows/file.pm
index 100bf9ae34dc..0519b06757c9 100644
--- a/solenv/bin/modules/installer/windows/file.pm
+++ b/solenv/bin/modules/installer/windows/file.pm
@@ -876,7 +876,7 @@ sub create_files_table
my %allfilecomponents = ();
my $counter = 0;
- if ( $^O =~ /cygwin/i ) { installer::worker::generate_cygwin_pathes($filesref); }
+ if ( $^O =~ /cygwin/i ) { installer::worker::generate_cygwin_paths($filesref); }
# The filenames must be collected because of uniqueness
# 01-44-~1.DAT, 01-44-~2.DAT, ...
diff --git a/solenv/bin/modules/installer/windows/msiglobal.pm b/solenv/bin/modules/installer/windows/msiglobal.pm
index f1d1e3df9998..9ff56c27cf90 100644
--- a/solenv/bin/modules/installer/windows/msiglobal.pm
+++ b/solenv/bin/modules/installer/windows/msiglobal.pm
@@ -171,7 +171,7 @@ sub generate_cab_file_list
installer::logger::include_timestamp_into_logfile("Performance Info: ddf file generation start");
- if ( $^O =~ /cygwin/i ) { installer::worker::generate_cygwin_pathes($filesref); }
+ if ( $^O =~ /cygwin/i ) { installer::worker::generate_cygwin_paths($filesref); }
if ( $installer::globals::use_packages_for_cabs )
{
diff --git a/solenv/bin/modules/installer/windows/strip.pm b/solenv/bin/modules/installer/windows/strip.pm
index 8cccba19de99..c31a0b120e76 100644
--- a/solenv/bin/modules/installer/windows/strip.pm
+++ b/solenv/bin/modules/installer/windows/strip.pm
@@ -116,7 +116,7 @@ sub strip_binaries
${$filelist}[$i]->{'is_executable'} = ( $filetypelist[$i] =~ /:.*PE executable/ );
}
- if ( $^O =~ /cygwin/i ) { installer::worker::generate_cygwin_pathes($filelist); }
+ if ( $^O =~ /cygwin/i ) { installer::worker::generate_cygwin_paths($filelist); }
for ( my $i = 0; $i <= $#{$filelist}; $i++ )
{
diff --git a/solenv/bin/modules/par2script/work.pm b/solenv/bin/modules/par2script/work.pm
index 9fc2aec67d91..2542b9ed5dcf 100644
--- a/solenv/bin/modules/par2script/work.pm
+++ b/solenv/bin/modules/par2script/work.pm
@@ -105,7 +105,7 @@ sub setparfiles
# for the par files
############################################
-sub make_complete_pathes_for_parfiles
+sub make_complete_paths_for_parfiles
{
my ($parfiles, $includes) = @_;
diff --git a/solenv/bin/par2script.pl b/solenv/bin/par2script.pl
index 06928ad68439..1f4fdf4335ad 100644
--- a/solenv/bin/par2script.pl
+++ b/solenv/bin/par2script.pl
@@ -47,7 +47,7 @@ par2script::parameter::outputparameter();
my $includes = par2script::work::setincludes($par2script::globals::includepathlist);
my $parfiles = par2script::work::setparfiles($par2script::globals::parfilelist);
-par2script::work::make_complete_pathes_for_parfiles($parfiles, $includes);
+par2script::work::make_complete_paths_for_parfiles($parfiles, $includes);
print "Reading par files\n";
my $parfilecontent = par2script::work::read_all_parfiles($parfiles);
diff --git a/solenv/bin/modules/installer/worker.pm b/solenv/bin/modules/installer/worker.pm
index 1d3d19a987a8..dd0c33966270 100644
--- a/solenv/bin/modules/installer/worker.pm
+++ b/solenv/bin/modules/installer/worker.pm
@@ -312,7 +312,7 @@ sub clean_output_tree
# array of include paths with $(LANG)
###########################################################
-sub get_language_specific_include_pathes
+sub get_language_specific_include_paths
{
my ( $patharrayref, $onelanguage ) = @_;
@@ -1818,7 +1818,7 @@ sub add_variables_from_inc_to_hashref
# Collecting all files from include paths
##############################################
-sub collect_all_files_from_includepathes
+sub collect_all_files_from_includepaths
{
my ($patharrayref) = @_;
@@ -1826,7 +1826,7 @@ sub collect_all_files_from_includepathes
installer::logger::print_message( "... reading include paths ...\n" );
# empty the global
- @installer::globals::allincludepathes =();
+ @installer::globals::allincludepaths =();
my $infoline;
for ( my $i = 0; $i <= $#{$patharrayref}; $i++ )
@@ -1864,11 +1864,11 @@ sub collect_all_files_from_includepathes
$allfileshash{$sourcefiles[$j]} = 1;
}
- push(@installer::globals::allincludepathes, \%allfileshash);
+ push(@installer::globals::allincludepaths, \%allfileshash);
}
}
- $installer::globals::include_pathes_read = 1;
+ $installer::globals::include_paths_read = 1;
installer::logger::globallog("Reading all directories: End");
push( @installer::globals::globallogfileinfo, "\n");
@@ -2123,12 +2123,12 @@ sub set_time_stamp
}
############################################################
# Generating pathes for cygwin (first version)
# This function has problems with cygwin, if $tmpfilename
# contains many thousand files (OpenOffice SDK).
############################################################
-sub generate_cygwin_pathes_old
+sub generate_cygwin_paths_old
{
my ($filesref) = @_;
@@ -2150,20 +2150,20 @@ sub generate_cygwin_pathes_old
}
#################################################
# Generating pathes for cygwin (second version)
# This function generates smaller files for
#################################################
-sub generate_cygwin_pathes
+sub generate_cygwin_paths
{
my ($filesref) = @_;
- installer::logger::include_timestamp_into_logfile("Starting generating cygwin pathes");
+ installer::logger::include_timestamp_into_logfile("Starting generating cygwin paths");
- my $infoline = "Generating cygwin pathes (generate_cygwin_pathes)\n";
+ my $infoline = "Generating cygwin paths (generate_cygwin_paths)\n";
push( @installer::globals::logfileinfo, $infoline);
- my $max = 5000; # number of pathes in one file
+ my $max = 5000; # number of paths in one file
my @pathcollector = ();
my $startnumber = 0;
@@ -2181,7 +2181,7 @@ sub generate_cygwin_pathes
my $temppath = $installer::globals::temppath;
$temppath =~ s/\Q$installer::globals::separator\E\s*$//;
$tmpfilename = $temppath . $installer::globals::separator . $tmpfilename;
- $infoline = "Creating temporary file for cygwin conversion: $tmpfilename (contains $counter pathes)\n";
+ $infoline = "Creating temporary file for cygwin conversion: $tmpfilename (contains $counter paths)\n";
push( @installer::globals::logfileinfo, $infoline);
if ( -f $tmpfilename ) { unlink $tmpfilename; }
@@ -2192,19 +2192,19 @@ sub generate_cygwin_pathes
chomp @cyg_sourcepathlist;
# Validating the array, it has to contain the correct number of values
- my $new_pathes = $#cyg_sourcepathlist + 1;
- if ( $new_pathes == $counter ) { $success = 1; }
+ my $new_paths = $#cyg_sourcepathlist + 1;
+ if ( $new_paths == $counter ) { $success = 1; }
if ($success)
{
- $infoline = "Success: Successfully converted to cygwin pathes!\n";
+ $infoline = "Success: Successfully converted to cygwin paths!\n";
push( @installer::globals::logfileinfo, $infoline);
}
else
{
- $infoline = "ERROR: Failed to convert to cygwin pathes!\n";
+ $infoline = "ERROR: Failed to convert to cygwin paths!\n";
push( @installer::globals::logfileinfo, $infoline);
- installer::exiter::exit_program("ERROR: Failed to convert to cygwin pathes!", "generate_cygwin_pathes");
+ installer::exiter::exit_program("ERROR: Failed to convert to cygwin paths!", "generate_cygwin_paths");
}
for ( my $j = 0; $j <= $#cyg_sourcepathlist; $j++ )
@@ -2228,11 +2228,11 @@ sub generate_cygwin_pathes
{
$infoline = "ERROR: No cygwin sourcepath defined for file ${$filesref}[$i]->{'sourcepath'}\n";
push( @installer::globals::logfileinfo, $infoline);
- installer::exiter::exit_program("ERROR: No cygwin sourcepath defined for file ${$filesref}[$i]->{'sourcepath'}!", "generate_cygwin_pathes");
+ installer::exiter::exit_program("ERROR: No cygwin sourcepath defined for file ${$filesref}[$i]->{'sourcepath'}!", "generate_cygwin_paths");
}
}
- installer::logger::include_timestamp_into_logfile("Ending generating cygwin pathes");
+ installer::logger::include_timestamp_into_logfile("Ending generating cygwin paths");
}
##############################################
@@ -2468,7 +2468,7 @@ sub put_license_into_setup
my $licenselanguage = "en-US"; # always english !
# my $licensefilename = "LICENSE"; # _" . $licenselanguage;
my $licensefilename = "license"; # . $licenselanguage . ".txt";
- my $licenseincludepatharrayref = get_language_specific_include_pathes($includepatharrayref, $licenselanguage);
+ my $licenseincludepatharrayref = get_language_specific_include_paths($includepatharrayref, $licenselanguage);
my $licenseref = installer::scriptitems::get_sourcepath_from_filename_and_includepath(\$licensefilename, $licenseincludepatharrayref, 0);
if ($$licenseref eq "") { installer::exiter::exit_program("ERROR: Could not find License file $licensefilename!", "put_license_into_setup"); }
@@ -2123,12 +2123,12 @@ sub set_time_stamp
}
############################################################
-# Generating pathes for cygwin (first version)
+# Generating paths for cygwin (first version)
# This function has problems with cygwin, if $tmpfilename
# contains many thousand files (OpenOffice SDK).
@@ -2150,20 +2150,20 @@ sub generate_cygwin_pathes_old
}
#################################################
-# Generating pathes for cygwin (second version)
+# Generating paths for cygwin (second version)
# This function generates smaller files for
#################################################
diff --git a/solenv/bin/modules/installer/ziplist.pm b/solenv/bin/modules/installer/ziplist.pm
index 6435445dc883..95b56389fd47 100644
--- a/solenv/bin/modules/installer/ziplist.pm
+++ b/solenv/bin/modules/installer/ziplist.pm
@@ -454,7 +454,7 @@ sub getinfofromziplist
# Replacing variables in include path
####################################################
-sub replace_all_variables_in_pathes
+sub replace_all_variables_in_paths
{
my ( $patharrayref, $variableshashref ) = @_;
@@ -481,7 +481,7 @@ sub replace_all_variables_in_pathes
# Replacing minor in include path
####################################################
-sub replace_minor_in_pathes
+sub replace_minor_in_paths
{
my ( $patharrayref ) = @_;
@@ -500,7 +500,7 @@ sub replace_minor_in_pathes
# Replacing packagetype in include path
####################################################
-sub replace_packagetype_in_pathes
+sub replace_packagetype_in_paths
{
my ( $patharrayref ) = @_;
@@ -542,7 +542,7 @@ sub remove_ending_separator
# Replacing languages in include path
####################################################
-sub replace_languages_in_pathes
+sub replace_languages_in_paths
{
my ( $patharrayref, $languagesref ) = @_;
@@ -576,7 +576,7 @@ sub replace_languages_in_pathes
# Checking if $newdir is empty
if ( ! installer::systemactions::is_empty_dir($newdir) )
{
- $installer::globals::refresh_includepathes = 1;
+ $installer::globals::refresh_includepaths = 1;
$infoline = "Directory $newdir exists and is not empty. Refreshing global file array is required.\n";
push( @installer::globals::logfileinfo, $infoline);
}
@@ -610,7 +610,7 @@ sub list_all_files_from_include_path
{
my ( $patharrayref) = @_;
- installer::logger::include_header_into_logfile("Include pathes:");
+ installer::logger::include_header_into_logfile("Include paths:");
for ( my $i = 0; $i <= $#{$patharrayref}; $i++ )
{
@@ -673,7 +673,7 @@ sub set_default_productversion_if_required
}
####################################################
# Removing .. in pathes
####################################################
sub simplify_path
@@ -696,10 +696,10 @@ sub simplify_path
}
####################################################
# Removing ending separators in pathes
####################################################
-sub resolve_relative_pathes
+sub resolve_relative_paths
{
my ( $patharrayref ) = @_;
@@ -673,7 +673,7 @@ sub set_default_productversion_if_required
}
####################################################
-# Removing .. in pathes
+# Removing .. in paths
####################################################
sub simplify_path
@@ -696,10 +696,10 @@ sub simplify_path
}
####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
####################################################